==> vnpy_novastrategy-0.3.0-py3-none-any.whl: vnpy_novastrategy/__init__.py <==
# MIT License
# 
# Copyright (c) 2024 VeighNa Global
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


from pathlib import Path
from datetime import datetime

from vnpy_evo.trader.app import BaseApp
from vnpy_evo.trader.constant import Direction, Interval
from vnpy_evo.trader.object import TickData, BarData, TradeData, OrderData
from vnpy_evo.trader.utility import BarGenerator, ArrayManager

from .base import APP_NAME
from .engine import StrategyEngine
from .template import StrategyTemplate
from .backtesting import BacktestingEngine


__version__ = "0.3.0"


class NovaStrategyApp(BaseApp):
    """"""

    app_name: str = APP_NAME
    app_module: str = __module__
    app_path: Path = Path(__file__).parent
    display_name: str = "Nova Strategy"
    engine_class: StrategyEngine = StrategyEngine
    widget_name: str = "NovaStrategyManager"
    icon_name: str = str(app_path.joinpath("ui", "strategy.ico"))

==> vnpy_novastrategy-0.4.0-py3-none-any.whl: vnpy_novastrategy/__init__.py <==
# MIT License
# 
# Copyright (c) 2024 VeighNa Global
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


from pathlib import Path
from datetime import datetime

from vnpy_evo.trader.app import BaseApp
from vnpy_evo.trader.constant import Direction, Interval
from vnpy_evo.trader.object import TickData, BarData, TradeData, OrderData
from vnpy_evo.trader.utility import BarGenerator, ArrayManager, round_to

from .base import APP_NAME
from .engine import StrategyEngine
from .template import StrategyTemplate, Parameter, Variable
from .backtesting import BacktestingEngine
from .table import DataTable, LiveDataTable, BacktestingDataTable
from .handler import TickHandler


__version__ = "0.4.0"


class NovaStrategyApp(BaseApp):
    """"""

    app_name: str = APP_NAME
    app_module: str = __module__
    app_path: Path = Path(__file__).parent
    display_name: str = "Nova Strategy"
    engine_class: StrategyEngine = StrategyEngine
    widget_name: str = "NovaStrategyManager"
    icon_name: str = str(app_path.joinpath("ui", "strategy.ico"))
